cmd

package
v0.9.95 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2024 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	CommitID  string
	Version   string
	Timestamp string
)
var RootCmd = &cobra.Command{
	Use:   "omnistrate-ctl",
	Short: "Manage your Omnistrate SaaS from the command line",
	Long: wordwrap.WrapString(`
Omnistrate CTL is a powerful command-line tool designed to simplify the creation, deployment, and management of your Omnistrate SaaS.

Key Features:
- Build Services: Create services from images or compose specs.
- Manage Service Plans: Efficiently handle your service plans.
- Deploy Instances: Deploy and manage instances with ease.

Resources:
- CTL Manual: https://ctl.omnistrate.cloud/omnistrate-ctl/
- Quick Start Guide: https://docs.omnistrate.com/getting-started/getting-started-with-ctl/

Use the CTL commands below to begin managing your services effectively.

`, 100),
	Run:               runRoot,
	DisableAutoGenTag: true,
	Aliases:           []string{"omctl"},
}

RootCmd represents the base command when called without any subcommands

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the RootCmd.

Types

This section is empty.

Jump to