login

package
v0.10.23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2025 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var LoginCmd = &cobra.Command{
	Use:          `login`,
	Short:        "Log in to the Omnistrate platform",
	Long:         `The login command is used to authenticate and log in to the Omnistrate platform.`,
	Example:      loginExample,
	RunE:         RunLogin,
	SilenceUsage: true,
}

LoginCmd represents the login command

Functions

func RunLogin added in v0.9.128

func RunLogin(cmd *cobra.Command, args []string) error

Types

type AccessTokenResponse

type AccessTokenResponse struct {
	JWTToken string `json:"jwt_token"`
}

AccessTokenResponse represents the response from the jwt token request

type DeviceCodeResponse

type DeviceCodeResponse struct {
	DeviceCode string `json:"device_code"`
	UserCode   string `json:"user_code"`
	ExpiresIn  int    `json:"expires_in"`
	Interval   int    `json:"interval"`
}

DeviceCodeResponse represents the response from the device code request

Jump to