upgrade

package
v0.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Cmd = &cobra.Command{
	Use:          "upgrade --version=[version]",
	Short:        "Upgrade Instance Deployments to a newer or older version",
	Long:         `This command helps you upgrade Instance Deployments to a newer or older version.`,
	Example:      upgradeExample,
	RunE:         run,
	SilenceUsage: true,
}
var UpgradePathIDs []string

Functions

This section is empty.

Types

type Args

type Args struct {
	ServiceID      string
	ProductTierID  string
	SourceVersion  string
	TargetVersion  string
	NotifyCustomer bool
	ScheduledDate  *string
}

type Res

type Res struct {
	UpgradePathID string
	InstanceIDs   []string
}

Directories

Path Synopsis

Jump to