Documentation
¶
Index ¶
- Constants
- type Account
- type CustomNetwork
- type CustomNetworkInfo
- type DeploymentCell
- type DeploymentCellHealthStatus
- type DeploymentCellTableView
- type DetailedEnvironment
- type Domain
- type EntityHealthInfo
- type Environment
- type HelmPackageInfo
- type Instance
- type Promotion
- type Resource
- type ResourceChangeSet
- type Service
- type ServicePlan
- type ServicePlanDetails
- type ServicePlanVersion
- type ServicePlanVersionDetails
- type Subscription
- type Upgrade
- type UpgradeMaintenanceAction
- type UpgradePathStatus
- type UpgradeStatus
- type UpgradeStatusDetail
Constants ¶
const ( EventTypeScheduled = "scheduled" EventTypeReminder = "reminder" EventTypeImmediate = "immediate" )
Maintenance event types
const ( CompletionStatusSuccess = "success" CompletionStatusCancelled = "cancelled" CompletionStatusSkipped = "skipped" )
Completion status types
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CustomNetwork ¶
type CustomNetwork struct {
CustomNetworkID string `json:"custom_network_id"`
CustomNetworkName string `json:"custom_network_name"`
CloudProvider string `json:"cloud_provider"`
Region string `json:"region"`
CIDR string `json:"cidr"`
OwningOrgID string `json:"owning_org_id"`
OwningOrgName string `json:"owning_org_name"`
AwsAccountID string `json:"aws_account_id"`
CloudProviderNativeNetworkId string `json:"cloud_provider_native_network_id"`
GcpProjectID string `json:"gcp_project_id"`
GcpProjectNumber string `json:"gcp_project_number"`
HostClusterID string `json:"host_cluster_id"`
}
type CustomNetworkInfo ¶ added in v0.13.11
type CustomNetworkInfo struct {
ID *string `json:"id,omitempty"`
Name *string `json:"name,omitempty"`
CIDR *string `json:"cidr,omitempty"`
OrgName *string `json:"org_name,omitempty"`
}
CustomNetworkInfo represents custom network configuration
type DeploymentCell ¶ added in v0.13.11
type DeploymentCell struct {
// Basic identification
ID string `json:"id"`
Key string `json:"key,omitempty"` // Optional key for easier identification
Status string `json:"status"`
Type string `json:"type"`
Description string `json:"description"`
// Infrastructure details
CloudProvider string `json:"cloud_provider"`
Region string `json:"region"`
RegionID string `json:"region_id"`
AccountID string `json:"account_id"`
AccountConfigID string `json:"account_config_id"`
IsCustomDeployment bool `json:"is_custom_deployment"`
// Deployment information
CurrentNumberOfDeployments int64 `json:"current_number_of_deployments"`
// Health status summary
HealthStatus DeploymentCellHealthStatus `json:"health_status"`
// Network configuration
CustomNetwork *CustomNetworkInfo `json:"custom_network,omitempty"`
// Kubernetes details
KubernetesDashboardEndpoint *string `json:"kubernetes_dashboard_endpoint,omitempty"`
// Helm packages
HelmPackages []HelmPackageInfo `json:"helm_packages,omitempty"`
// Additional metadata
Role *string `json:"role,omitempty"`
ModelType *string `json:"model_type,omitempty"`
// Customer metadata
CustomerEmail *string `json:"customer_email,omitempty"`
CustomerOrganizationName *string `json:"customer_organization_name,omitempty"`
}
DeploymentCell represents a complete view of a host cluster/deployment cell
func (DeploymentCell) ToTableView ¶ added in v0.13.11
func (dc DeploymentCell) ToTableView() DeploymentCellTableView
ToTableView converts a DeploymentCell to a table-friendly view
type DeploymentCellHealthStatus ¶ added in v0.13.11
type DeploymentCellHealthStatus struct {
OverallStatus string `json:"overall_status"`
StatusMessage *string `json:"status_message,omitempty"`
TotalEntities int64 `json:"total_entities"`
HealthyEntities int64 `json:"healthy_entities"`
FailedEntities int64 `json:"failed_entities"`
EntitiesByType map[string]int64 `json:"entities_by_type,omitempty"`
HealthyEntitiesByType map[string]int64 `json:"healthy_entities_by_type,omitempty"`
FailedEntitiesByType map[string]int64 `json:"failed_entities_by_type,omitempty"`
FailedEntityDetails []EntityHealthInfo `json:"failed_entity_details,omitempty"`
KubernetesControlPlaneVersion string `json:"kubernetes_control_plane_version,omitempty"`
}
DeploymentCellHealthStatus represents the health status of a deployment cell
func (DeploymentCellHealthStatus) String ¶ added in v0.13.11
func (h DeploymentCellHealthStatus) String() string
String provides a readable representation of the health status for table display
type DeploymentCellTableView ¶ added in v0.13.11
type DeploymentCellTableView struct {
ID string `json:"id"`
CustomerEmail *string `json:"customer_email"`
CustomerOrganizationName *string `json:"customer_organization_name"`
Status string `json:"status"`
Type string `json:"type"`
CloudProvider string `json:"cloud_provider"`
Region string `json:"region"`
CurrentNumberOfDeployments int64 `json:"current_number_of_deployments"`
HealthStatus string `json:"health_status"`
}
DeploymentCellTableView returns a simplified view of the deployment cell for table display
type DetailedEnvironment ¶
type DetailedEnvironment struct {
EnvironmentID string `json:"environment_id,omitempty"`
EnvironmentName string `json:"environment_name,omitempty"`
EnvironmentType string `json:"environment_type,omitempty"`
ServiceID string `json:"service_id,omitempty"`
ServiceName string `json:"service_name,omitempty"`
SourceEnvName string `json:"source_env_name,omitempty"`
PromoteStatus string `json:"promote_status,omitempty"`
SaaSPortalStatus string `json:"saas_portal_status,omitempty"`
SaaSPortalURL string `json:"saas_portal_url,omitempty"`
}
type EntityHealthInfo ¶ added in v0.13.11
type EntityHealthInfo struct {
Identifier string `json:"identifier"`
Type string `json:"type"`
SyncStatus string `json:"sync_status"`
Error *string `json:"error,omitempty"`
}
EntityHealthInfo represents detailed health information for a specific entity
type Environment ¶
type HelmPackageInfo ¶ added in v0.13.11
type HelmPackageInfo struct {
ChartName string `json:"chart_name"`
ChartVersion string `json:"chart_version"`
ChartRepoName string `json:"chart_repo_name"`
ChartRepoURL string `json:"chart_repo_url"`
Namespace string `json:"namespace"`
ChartValues map[string]interface{} `json:"chart_values,omitempty"`
}
HelmPackageInfo represents a Helm package installed on the cluster
type Instance ¶
type Instance struct {
InstanceID string `json:"instance_id"`
Service string `json:"service"`
Environment string `json:"environment"`
Plan string `json:"plan"`
Version string `json:"version"`
Resource string `json:"resource"`
CloudProvider string `json:"cloud_provider"`
Region string `json:"region"`
Status string `json:"status"`
SubscriptionID string `json:"subscription_id"`
}
type Promotion ¶
type Promotion struct {
ServiceID string `json:"service_id"`
ServiceName string `json:"service_name"`
SourceEnvironmentID string `json:"source_environment_id"`
SourceEnvironmentName string `json:"source_environment_name"`
TargetEnvID string `json:"target_env_id"`
TargetEnvName string `json:"target_env_name"`
PromoteStatus string `json:"promote_status"`
}
type Resource ¶
type Resource struct {
ResourceID string `json:"resource_id,omitempty"`
ResourceName string `json:"resource_name,omitempty"`
ResourceDescription string `json:"resource_description,omitempty"`
ResourceType string `json:"resource_type,omitempty"`
ActionHooks any `json:"action_hooks,omitempty"`
AdditionalSecurityContext any `json:"additional_security_context,omitempty"`
BackupConfiguration any `json:"backup_configuration,omitempty"`
Capabilities any `json:"capabilities,omitempty"`
CustomLabels any `json:"custom_labels,omitempty"`
CustomSysCTLs any `json:"custom_sysctls,omitempty"`
CustomULimits any `json:"custom_ulimits,omitempty"`
Dependencies any `json:"dependencies,omitempty"`
EnvironmentVariables any `json:"environment_variables,omitempty"`
FileSystemConfiguration any `json:"file_system_configuration,omitempty"`
HelmChartConfiguration any `json:"helm_chart_configuration,omitempty"`
KustomizeConfiguration any `json:"kustomize_configuration,omitempty"`
L4LoadBalancerConfiguration any `json:"l4_load_balancer_configuration,omitempty"`
L7LoadBalancerConfiguration any `json:"l7_load_balancer_configuration,omitempty"`
OperatorCRDConfiguration any `json:"operator_crd_configuration,omitempty"`
}
type ResourceChangeSet ¶
type ResourceChangeSet struct {
ResourceName string `json:"resource_name,omitempty"`
ResourceChanges any `json:"resource_changes,omitempty"`
ProductTierFeatureChanges any `json:"product_tier_feature_changes,omitempty"`
ImageConfigChanges any `json:"image_config_changes,omitempty"`
InfraConfigChanges any `json:"infra_config_changes,omitempty"`
}
type ServicePlan ¶
type ServicePlan struct {
PlanID string `json:"plan_id,omitempty"`
PlanName string `json:"plan_name,omitempty"`
ServiceID string `json:"service_id,omitempty"`
ServiceName string `json:"service_name,omitempty"`
Environment string `json:"environment,omitempty"`
DeploymentType string `json:"deployment_type,omitempty"`
TenancyType string `json:"tenancy_type,omitempty"`
}
type ServicePlanDetails ¶
type ServicePlanDetails struct {
PlanID string `json:"plan_id,omitempty"`
PlanName string `json:"plan_name,omitempty"`
ServiceID string `json:"service_id,omitempty"`
ServiceName string `json:"service_name,omitempty"`
Environment string `json:"environment,omitempty"`
DeploymentType string `json:"deployment_type,omitempty"`
TenancyType string `json:"tenancy_type,omitempty"`
EnabledFeatures any `json:"enabled_features,omitempty"`
Resources []Resource `json:"resources,omitempty"`
PendingChanges map[string]ResourceChangeSet `json:"pending_changes,omitempty"`
}
type ServicePlanVersion ¶
type ServicePlanVersion struct {
PlanID string `json:"plan_id,omitempty"`
PlanName string `json:"plan_name,omitempty"`
ServiceID string `json:"service_id,omitempty"`
ServiceName string `json:"service_name,omitempty"`
Environment string `json:"environment,omitempty"`
Version string `json:"version,omitempty"`
ReleaseDescription string `json:"release_description,omitempty"`
VersionSetStatus string `json:"version_set_status,omitempty"`
}
type ServicePlanVersionDetails ¶
type ServicePlanVersionDetails struct {
PlanID string `json:"plan_id,omitempty"`
PlanName string `json:"plan_name,omitempty"`
ServiceID string `json:"service_id,omitempty"`
ServiceName string `json:"service_name,omitempty"`
Environment string `json:"environment,omitempty"`
Version string `json:"version,omitempty"`
ReleaseDescription string `json:"release_description,omitempty"`
VersionSetStatus string `json:"version_set_status,omitempty"`
EnabledFeatures any `json:"enabled_features,omitempty"`
Resources []Resource `json:"resources,omitempty"`
}
type Subscription ¶
type Subscription struct {
SubscriptionID string `json:"subscription_id"`
ServiceID string `json:"service_id"`
ServiceName string `json:"service_name"`
PlanID string `json:"plan_id"`
PlanName string `json:"plan_name"`
Environment string `json:"environment"`
SubscriptionOwnerName string `json:"subscription_owner_name"`
SubscriptionOwnerEmail string `json:"subscription_owner_email"`
Status string `json:"status"`
}
type UpgradeMaintenanceAction ¶ added in v0.10.30
type UpgradeMaintenanceAction string
const ( PauseAction UpgradeMaintenanceAction = "pause" ResumeAction UpgradeMaintenanceAction = "resume" CancelAction UpgradeMaintenanceAction = "cancel" NotifyCustomerAction UpgradeMaintenanceAction = "notify-customer" SkipInstancesAction UpgradeMaintenanceAction = "skip-instances" )
Maintenance actions
func (UpgradeMaintenanceAction) String ¶ added in v0.10.30
func (a UpgradeMaintenanceAction) String() string
type UpgradePathStatus ¶ added in v0.10.36
type UpgradePathStatus string
UpgradePathStatus represents the status of an upgrade path
const ( InProgress UpgradePathStatus = "IN_PROGRESS" Scheduled UpgradePathStatus = "SCHEDULED" Complete UpgradePathStatus = "COMPLETE" Failed UpgradePathStatus = "FAILED" Cancelled UpgradePathStatus = "CANCELLED" Skipped UpgradePathStatus = "SKIPPED" Verifying UpgradePathStatus = "VERIFYING" )
func (UpgradePathStatus) String ¶ added in v0.10.36
func (v UpgradePathStatus) String() string
type UpgradeStatus ¶
type UpgradeStatus struct {
UpgradeID string `json:"upgrade_id"`
Total int64 `json:"total"`
Pending int64 `json:"pending"`
InProgress int64 `json:"in_progress"`
Completed int64 `json:"completed"`
Failed int64 `json:"failed"`
Scheduled *int `json:"scheduled,omitempty"`
Skipped int64 `json:"skipped"`
Status string `json:"status"`
NotifyCustomer bool `json:"notify_customer"`
}
type UpgradeStatusDetail ¶
type UpgradeStatusDetail struct {
UpgradeID string `json:"upgrade_id"`
InstanceID string `json:"instance_id"`
UpgradeStartTime string `json:"upgrade_start_time"`
PlannedExecutionDate *string `json:"planned_execution_date"`
UpgradeEndTime string `json:"upgrade_end_time"`
UpgradeStatus string `json:"upgrade_status"`
}