Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var LoginCmd = &cobra.Command{ Use: `login`, Short: "Log in to the Omnistrate platform", Long: `The login command is used to authenticate and log in to the Omnistrate platform.`, Example: loginExample, RunE: RunLogin, SilenceUsage: true, }
LoginCmd represents the login command
Functions ¶
Types ¶
type AccessTokenResponse ¶
type AccessTokenResponse struct {
JWTToken string `json:"jwt_token"`
}
AccessTokenResponse represents the response from the jwt token request
Click to show internal directories.
Click to hide internal directories.