Documentation
¶
Index ¶
- Constants
- Variables
- func AskVerifyAccountIfAny(ctx context.Context)
- func AskVerifyDomainIfAny(ctx context.Context)
- func BuildServiceFromComposeSpec(ctx context.Context, token string, ...) (*openapiclient.BuildServiceFromComposeSpecResult, error)
- func BuildServiceFromServicePlanSpec(ctx context.Context, token string, ...) (*openapiclient.BuildServiceFromServicePlanSpecResult, error)
- func CheckIfContainerImageAccessible(ctx context.Context, token string, imageRegistry, image string, ...) (res *openapiclient.CheckIfContainerImageAccessibleResult, err error)
- func CreateAccount(ctx context.Context, token string, ...) (string, error)
- func CreateDomain(ctx context.Context, ...) error
- func CreateResourceInstance(ctx context.Context, token string, serviceProviderId string, serviceKey string, ...) (res *openapiclientfleet.CreateResourceInstanceResponseBody, err error)
- func CreateServiceEnvironment(ctx context.Context, token string, name, description, serviceID string, ...) (string, error)
- func CreateServicesOrchestration(ctx context.Context, token string, orchestrationCreateDSL string) (res *openapiclientfleet.CreateResourceInstanceResponseBody, err error)
- func CreateUpgradePath(ctx context.Context, ...) (string, error)
- func DeleteAccount(ctx context.Context, token, accountConfigID string) error
- func DeleteDomain(ctx context.Context, token, environmentType string) error
- func DeleteHelmChart(ctx context.Context, token, chartName, chartVersion string) (err error)
- func DeleteProductTier(ctx context.Context, token, serviceID, productTierID string) (err error)
- func DeleteResourceInstance(ctx context.Context, ...) (err error)
- func DeleteService(ctx context.Context, token, serviceID string) error
- func DeleteServiceEnvironment(ctx context.Context, token, serviceID, serviceEnvironmentID string) error
- func DeleteServicesOrchestration(ctx context.Context, token, id string) (err error)
- func DescribeAccount(ctx context.Context, token string, id string) (*openapiclient.DescribeAccountConfigResult, error)
- func DescribeHelmChart(ctx context.Context, token, chartName, chartVersion string) (helmPackage *openapiclient.HelmPackage, err error)
- func DescribeLatestVersion(ctx context.Context, token, serviceID, productTierID string) (*openapiclient.TierVersionSet, error)
- func DescribePendingChanges(ctx context.Context, token, serviceID, serviceAPIID, productTierID string) (*openapiclientv1.DescribePendingChangesResult, error)
- func DescribeProductTier(ctx context.Context, token, serviceID, productTierID string) (productTier *openapiclientv1.DescribeProductTierResult, err error)
- func DescribeResource(ctx context.Context, token, serviceID, resourceID string, ...) (resp *openapiclient.DescribeResourceResult, err error)
- func DescribeResourceInstance(ctx context.Context, token string, serviceID, environmentID, instanceID string) (resp *openapiclientfleet.ResourceInstance, err error)
- func DescribeService(ctx context.Context, token, serviceID string) (*openapiclient.DescribeServiceResult, error)
- func DescribeServiceEnvironment(ctx context.Context, token, serviceID, serviceEnvironmentID string) (*openapiclientv1.DescribeServiceEnvironmentResult, error)
- func DescribeServiceModel(ctx context.Context, token, serviceID, serviceModelID string) (serviceModel *openapiclient.DescribeServiceModelResult, err error)
- func DescribeServiceOffering(ctx context.Context, ...) (res *openapiclientfleet.InventoryDescribeServiceOfferingResult, err error)
- func DescribeServiceOfferingResource(ctx context.Context, ...) (res *openapiclientfleet.InventoryDescribeServiceOfferingResourceResult, ...)
- func DescribeServicesOrchestration(ctx context.Context, token string, id string) (resp *openapiclientfleet.FleetDescribeServicesOrchestrationResult, err error)
- func DescribeSubscription(ctx context.Context, token string, serviceID, environmentID, instanceID string) (resp *openapiclientfleet.FleetDescribeSubscriptionResult, err error)
- func DescribeUpgradePath(ctx context.Context, token, serviceID, productTierID, upgradePathID string) (*openapiclientfleet.UpgradePath, error)
- func DescribeUser(ctx context.Context, token string) (*openapiclient.DescribeUserResult, error)
- func DescribeVersionSet(ctx context.Context, token, serviceID, productTierID, version string) (*openapiclient.TierVersionSet, error)
- func DisableServiceModelFeature(ctx context.Context, token, serviceID, serviceModelID, featureName string) (err error)
- func EnableServiceModelFeature(ctx context.Context, token, serviceID, serviceModelID, featureName string, ...) (err error)
- func FindEnvironment(ctx context.Context, token, serviceID, environmentType string) (*openapiclientv1.DescribeServiceEnvironmentResult, error)
- func FindLatestVersion(ctx context.Context, token, serviceID, productTierID string) (string, error)
- func FindPreferredVersion(ctx context.Context, token, serviceID, productTierID string) (string, error)
- func FleetCreateCustomNetwork(ctx context.Context, token string, cloudProviderName string, ...) (customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
- func FleetDeleteCustomNetwork(ctx context.Context, token string, customNetworkId string) (err error)
- func FleetDescribeCustomNetwork(ctx context.Context, token string, id string) (customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
- func FleetListCustomNetworks(ctx context.Context, token string, cloudProviderName *string, ...) (customNetworks *openapiclientfleet.FleetListCustomNetworksResult, err error)
- func FleetUpdateCustomNetwork(ctx context.Context, token string, id string, updatedName *string) (customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
- func GenerateComposeSpecFromContainerImage(ctx context.Context, token string, ...) (res *openapiclient.GenerateComposeSpecFromContainerImageResult, err error)
- func GetCloudProviderByName(ctx context.Context, token string, cloudProvider string) (string, error)
- func GetDefaultDeploymentConfigID(ctx context.Context, token string) (string, error)
- func GetInstanceDeploymentEntity(ctx context.Context, token string, instanceID string, deploymentType string, ...) (output string, err error)
- func ListAccounts(ctx context.Context, token string, cloudProvider string) (*openapiclient.ListAccountConfigResult, error)
- func ListDomains(ctx context.Context, token string) (*openapiclientv1.ListSaaSPortalCustomDomainsResult, error)
- func ListEligibleInstancesPerUpgrade(ctx context.Context, token, serviceID, productTierID, upgradePathID string) ([]openapiclientfleet.InstanceUpgrade, error)
- func ListHelmChartInstallations(ctx context.Context, token string, hostClusterID string) (...)
- func ListHelmCharts(ctx context.Context, token string) (helmPackages *openapiclient.ListHelmPackagesResult, err error)
- func ListServiceEnvironments(ctx context.Context, token, serviceID string) (*openapiclientv1.ListServiceEnvironmentsResult, error)
- func ListServiceOfferings(ctx context.Context, token, orgID string) (inventory *openapiclientfleet.InventoryListServiceOfferingsResult, err error)
- func ListServices(ctx context.Context, token string) (*openapiclient.ListServiceResult, error)
- func ListServicesOrchestration(ctx context.Context, token string, environmentType string) (resp []openapiclientfleet.FleetDescribeServicesOrchestrationResult, err error)
- func ListVersions(ctx context.Context, token, serviceID, productTierID string) (*openapiclient.ListTierVersionSetsResult, error)
- func LoginWithIdentityProvider(ctx context.Context, deviceCode, identityProviderName string) (string, error)
- func LoginWithPassword(ctx context.Context, email string, pass string) (string, error)
- func ManageLifecycle(ctx context.Context, token, serviceID, productTierID, upgradePathID string, ...) (*openapiclientfleet.UpgradePath, error)
- func ManageLifecycleWithPayload(ctx context.Context, token, serviceID, productTierID, upgradePathID string, ...) (*openapiclientfleet.UpgradePath, error)
- func ModifyServicesOrchestration(ctx context.Context, token string, id string, orchestrationModifyDSL string) (err error)
- func PatchInstanceDeploymentEntity(ctx context.Context, token string, instanceID string, deploymentType string, ...) (err error)
- func PauseInstanceDeploymentEntity(ctx context.Context, token string, instanceID string, deploymentType string, ...) (err error)
- func PrintAccountNotVerifiedWarning(account *openapiclient.DescribeAccountConfigResult)
- func PrintDomainNotVerifiedWarningMsg(domain, clusterEndpoint string)
- func PrintNextStepVerifyAccountMsg(account *openapiclient.DescribeAccountConfigResult)
- func PrintNextStepVerifyDomainMsg(clusterEndpoint string)
- func PrintNextStepsAfterBuildMsg()
- func PromoteServiceEnvironment(ctx context.Context, token, serviceID, serviceEnvironmentID string) error
- func PromoteServiceEnvironmentStatus(ctx context.Context, token, serviceID, serviceEnvironmentID string) (resp []openapiclientv1.EnvironmentPromotionStatus, err error)
- func ReleaseServicePlan(ctx context.Context, token, serviceID, serviceAPIID, productTierID string, ...) error
- func RestartResourceInstance(ctx context.Context, token string, ...) (err error)
- func ResumeInstanceDeploymentEntity(ctx context.Context, token string, instanceID string, deploymentType string, ...) (err error)
- func SaveHelmChart(ctx context.Context, token string, chartName string, chartVersion string, ...) (helmPackage openapiclient.HelmPackage, err error)
- func SearchInventory(ctx context.Context, token, query string) (*openapiclientfleet.SearchInventoryResult, error)
- func SetDefaultServicePlan(ctx context.Context, token, serviceID, productTierID, version string) (*openapiclient.TierVersionSet, error)
- func StartResourceInstance(ctx context.Context, token string, ...) (err error)
- func StopResourceInstance(ctx context.Context, token string, ...) (err error)
- func UpdateResourceInstance(ctx context.Context, token string, serviceID, environmentID, instanceID string, ...) (err error)
- func UpdateResourceInstanceDebugMode(ctx context.Context, token string, serviceID, environmentID, instanceID string, ...) (err error)
- type InspectAZItem
- type InspectPVCItem
- type InspectPVItem
- type InspectPodItem
- type InspectStorageClassItem
- type InspectVMItem
- type InspectWorkloadItem
- type K8sClientConfig
- type K8sInspectClient
- type K8sInspectClientImpl
- type LeveledLogger
- type ResourceList
- type ResourceRequirements
Constants ¶
const ( AccountNotVerifiedWarningMsgTemplate = `` /* 453-byte string literal not displayed */ NextStepVerifyAccountMsgTemplate = `` /* 369-byte string literal not displayed */ AwsCloudFormationGuideURL = "https://youtu.be/Mu-4jppldwk" AwsGcpTerraformScriptsURL = "https://github.com/omnistrate-oss/account-setup" AwsGcpTerraformGuideURL = "https://youtu.be/eKktc4QKgaA" )
const ( DomainNotVerifiedWarningMsgTemplate = `` /* 247-byte string literal not displayed */ NextStepVerifyDomainMsgTemplate = `` /* 211-byte string literal not displayed */ )
const (
NextStepsAfterBuildMsgTemplate = `` /* 170-byte string literal not displayed */
)
Variables ¶
var (
ErrEnvironmentNotFound = errors.New("environment not found")
)
Functions ¶
func AskVerifyAccountIfAny ¶
func AskVerifyDomainIfAny ¶
func BuildServiceFromComposeSpec ¶ added in v0.10.31
func BuildServiceFromComposeSpec(ctx context.Context, token string, request openapiclient.BuildServiceFromComposeSpecRequest2) (*openapiclient.BuildServiceFromComposeSpecResult, error)
func BuildServiceFromServicePlanSpec ¶ added in v0.10.31
func BuildServiceFromServicePlanSpec(ctx context.Context, token string, request openapiclient.BuildServiceFromServicePlanSpecRequest2) (*openapiclient.BuildServiceFromServicePlanSpecResult, error)
func CheckIfContainerImageAccessible ¶
func CheckIfContainerImageAccessible(ctx context.Context, token string, imageRegistry, image string, userName, password *string) (res *openapiclient.CheckIfContainerImageAccessibleResult, err error)
func CreateAccount ¶
func CreateAccount(ctx context.Context, token string, accountConfig openapiclient.CreateAccountConfigRequest2) (string, error)
func CreateDomain ¶
func CreateResourceInstance ¶ added in v0.9.129
func CreateResourceInstance(ctx context.Context, token string, serviceProviderId string, serviceKey string, serviceAPIVersion string, serviceEnvironmentKey string, serviceModelKey string, productTierKey string, resourceKey string, request openapiclientfleet.FleetCreateResourceInstanceRequest2) (res *openapiclientfleet.CreateResourceInstanceResponseBody, err error)
func CreateServicesOrchestration ¶ added in v0.10.3
func CreateServicesOrchestration( ctx context.Context, token string, orchestrationCreateDSL string, ) ( res *openapiclientfleet.CreateResourceInstanceResponseBody, err error, )
func CreateUpgradePath ¶
func DeleteHelmChart ¶
func DeleteProductTier ¶
func DeleteResourceInstance ¶ added in v0.9.129
func DeleteServicesOrchestration ¶ added in v0.10.3
func DescribeAccount ¶
func DescribeAccount(ctx context.Context, token string, id string) (*openapiclient.DescribeAccountConfigResult, error)
func DescribeHelmChart ¶
func DescribeHelmChart(ctx context.Context, token, chartName, chartVersion string) (helmPackage *openapiclient.HelmPackage, err error)
func DescribeLatestVersion ¶ added in v0.10.16
func DescribeLatestVersion(ctx context.Context, token, serviceID, productTierID string) (*openapiclient.TierVersionSet, error)
func DescribePendingChanges ¶
func DescribePendingChanges(ctx context.Context, token, serviceID, serviceAPIID, productTierID string) (*openapiclientv1.DescribePendingChangesResult, error)
func DescribeProductTier ¶
func DescribeProductTier(ctx context.Context, token, serviceID, productTierID string) (productTier *openapiclientv1.DescribeProductTierResult, err error)
func DescribeResource ¶
func DescribeResource(ctx context.Context, token, serviceID, resourceID string, productTierID, productTierVersion *string) (resp *openapiclient.DescribeResourceResult, err error)
func DescribeResourceInstance ¶
func DescribeResourceInstance(ctx context.Context, token string, serviceID, environmentID, instanceID string) (resp *openapiclientfleet.ResourceInstance, err error)
func DescribeService ¶
func DescribeService(ctx context.Context, token, serviceID string) (*openapiclient.DescribeServiceResult, error)
func DescribeServiceEnvironment ¶
func DescribeServiceEnvironment(ctx context.Context, token, serviceID, serviceEnvironmentID string) (*openapiclientv1.DescribeServiceEnvironmentResult, error)
func DescribeServiceModel ¶
func DescribeServiceModel(ctx context.Context, token, serviceID, serviceModelID string) (serviceModel *openapiclient.DescribeServiceModelResult, err error)
func DescribeServiceOffering ¶
func DescribeServiceOffering(ctx context.Context, token, serviceID, productTierID, productTierVersion string) (res *openapiclientfleet.InventoryDescribeServiceOfferingResult, err error)
func DescribeServiceOfferingResource ¶
func DescribeServiceOfferingResource(ctx context.Context, token, serviceID, resourceID, instanceID, productTierID, productTierVersion string) (res *openapiclientfleet.InventoryDescribeServiceOfferingResourceResult, err error)
func DescribeServicesOrchestration ¶ added in v0.10.3
func DescribeServicesOrchestration(ctx context.Context, token string, id string) (resp *openapiclientfleet.FleetDescribeServicesOrchestrationResult, err error)
func DescribeSubscription ¶
func DescribeSubscription(ctx context.Context, token string, serviceID, environmentID, instanceID string) (resp *openapiclientfleet.FleetDescribeSubscriptionResult, err error)
func DescribeUpgradePath ¶
func DescribeUpgradePath(ctx context.Context, token, serviceID, productTierID, upgradePathID string) (*openapiclientfleet.UpgradePath, error)
func DescribeUser ¶
func DescribeUser(ctx context.Context, token string) (*openapiclient.DescribeUserResult, error)
func DescribeVersionSet ¶
func DescribeVersionSet(ctx context.Context, token, serviceID, productTierID, version string) (*openapiclient.TierVersionSet, error)
func FindEnvironment ¶
func FindEnvironment(ctx context.Context, token, serviceID, environmentType string) (*openapiclientv1.DescribeServiceEnvironmentResult, error)
func FindLatestVersion ¶
func FindPreferredVersion ¶
func FleetCreateCustomNetwork ¶ added in v0.9.113
func FleetCreateCustomNetwork( ctx context.Context, token string, cloudProviderName string, cloudProviderRegion string, cidr string, name *string) ( customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
func FleetDeleteCustomNetwork ¶ added in v0.9.113
func FleetDescribeCustomNetwork ¶ added in v0.9.110
func FleetDescribeCustomNetwork( ctx context.Context, token string, id string) ( customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
func FleetListCustomNetworks ¶ added in v0.9.110
func FleetListCustomNetworks( ctx context.Context, token string, cloudProviderName *string, cloudProviderRegion *string) ( customNetworks *openapiclientfleet.FleetListCustomNetworksResult, err error)
func FleetUpdateCustomNetwork ¶ added in v0.10.11
func FleetUpdateCustomNetwork( ctx context.Context, token string, id string, updatedName *string) ( customNetwork *openapiclientfleet.FleetCustomNetwork, err error)
func GenerateComposeSpecFromContainerImage ¶
func GenerateComposeSpecFromContainerImage(ctx context.Context, token string, request openapiclient.GenerateComposeSpecFromContainerImageRequest2) (res *openapiclient.GenerateComposeSpecFromContainerImageResult, err error)
func GetCloudProviderByName ¶
func GetInstanceDeploymentEntity ¶ added in v0.10.21
func ListAccounts ¶
func ListAccounts(ctx context.Context, token string, cloudProvider string) (*openapiclient.ListAccountConfigResult, error)
func ListDomains ¶
func ListDomains(ctx context.Context, token string) (*openapiclientv1.ListSaaSPortalCustomDomainsResult, error)
func ListEligibleInstancesPerUpgrade ¶
func ListEligibleInstancesPerUpgrade(ctx context.Context, token, serviceID, productTierID, upgradePathID string) ([]openapiclientfleet.InstanceUpgrade, error)
func ListHelmChartInstallations ¶
func ListHelmChartInstallations(ctx context.Context, token string, hostClusterID string) (helmPackageInstallations *openapiclientfleet.ListHelmPackageInstallationsResult, err error)
func ListHelmCharts ¶
func ListHelmCharts(ctx context.Context, token string) (helmPackages *openapiclient.ListHelmPackagesResult, err error)
func ListServiceEnvironments ¶
func ListServiceEnvironments(ctx context.Context, token, serviceID string) (*openapiclientv1.ListServiceEnvironmentsResult, error)
func ListServiceOfferings ¶
func ListServiceOfferings(ctx context.Context, token, orgID string) (inventory *openapiclientfleet.InventoryListServiceOfferingsResult, err error)
func ListServices ¶
func ListServices(ctx context.Context, token string) (*openapiclient.ListServiceResult, error)
func ListServicesOrchestration ¶ added in v0.10.3
func ListServicesOrchestration(ctx context.Context, token string, environmentType string) (resp []openapiclientfleet.FleetDescribeServicesOrchestrationResult, err error)
func ListVersions ¶ added in v0.10.17
func ListVersions(ctx context.Context, token, serviceID, productTierID string) (*openapiclient.ListTierVersionSetsResult, error)
func LoginWithPassword ¶
func ManageLifecycle ¶ added in v0.10.30
func ManageLifecycle(ctx context.Context, token, serviceID, productTierID, upgradePathID string, action model.UpgradeMaintenanceAction) (*openapiclientfleet.UpgradePath, error)
func ManageLifecycleWithPayload ¶ added in v0.10.36
func ManageLifecycleWithPayload(ctx context.Context, token, serviceID, productTierID, upgradePathID string, action model.UpgradeMaintenanceAction, actionPayload map[string]interface{}) (*openapiclientfleet.UpgradePath, error)
func ModifyServicesOrchestration ¶ added in v0.10.5
func PatchInstanceDeploymentEntity ¶ added in v0.10.21
func PauseInstanceDeploymentEntity ¶ added in v0.10.21
func PrintAccountNotVerifiedWarning ¶
func PrintAccountNotVerifiedWarning(account *openapiclient.DescribeAccountConfigResult)
func PrintDomainNotVerifiedWarningMsg ¶
func PrintDomainNotVerifiedWarningMsg(domain, clusterEndpoint string)
func PrintNextStepVerifyAccountMsg ¶
func PrintNextStepVerifyAccountMsg(account *openapiclient.DescribeAccountConfigResult)
func PrintNextStepVerifyDomainMsg ¶
func PrintNextStepVerifyDomainMsg(clusterEndpoint string)
func PrintNextStepsAfterBuildMsg ¶
func PrintNextStepsAfterBuildMsg()
func PromoteServiceEnvironmentStatus ¶
func PromoteServiceEnvironmentStatus(ctx context.Context, token, serviceID, serviceEnvironmentID string) (resp []openapiclientv1.EnvironmentPromotionStatus, err error)
func ReleaseServicePlan ¶
func RestartResourceInstance ¶
func ResumeInstanceDeploymentEntity ¶ added in v0.10.21
func SaveHelmChart ¶
func SearchInventory ¶
func SearchInventory(ctx context.Context, token, query string) (*openapiclientfleet.SearchInventoryResult, error)
func SetDefaultServicePlan ¶
func SetDefaultServicePlan(ctx context.Context, token, serviceID, productTierID, version string) (*openapiclient.TierVersionSet, error)
func StartResourceInstance ¶
func StopResourceInstance ¶
func UpdateResourceInstance ¶
Types ¶
type InspectAZItem ¶ added in v0.10.34
type InspectAZItem struct {
Name string
VMs []InspectVMItem
}
InspectAZItem represents an availability zone
type InspectPVCItem ¶ added in v0.10.34
type InspectPVCItem struct {
Name string
Size string
Status string
PVName string
StorageClass string
AccessModes []string
}
InspectPVCItem represents a persistent volume claim
type InspectPVItem ¶ added in v0.10.34
type InspectPVItem struct {
Name string
Size string
Status string
StorageClass string
AccessModes []string
VolumeType string
PVCName string
PVCNamespace string
}
InspectPVItem represents a persistent volume
type InspectPodItem ¶ added in v0.10.34
type InspectPodItem struct {
Name string
Status string
NodeName string
Namespace string
PVCs []InspectPVCItem // PVCs attached to this pod
Labels map[string]string
Resources ResourceRequirements
}
InspectPodItem represents a pod
type InspectStorageClassItem ¶ added in v0.10.34
type InspectStorageClassItem struct {
Name string
Provisioner string
Parameters map[string]string
PVs []InspectPVItem
}
InspectStorageClassItem represents a storage class
type InspectVMItem ¶ added in v0.10.34
type InspectVMItem struct {
Name string
InstanceType string
VCPUs int
MemoryGB float64
Pods []InspectPodItem
}
InspectVMItem represents a node in the cluster
type InspectWorkloadItem ¶ added in v0.10.34
type InspectWorkloadItem struct {
Type string // StatefulSet or Deployment
Name string
AZs map[string][]InspectPodItem
}
InspectWorkloadItem represents a workload (StatefulSet or Deployment)
type K8sClientConfig ¶ added in v0.10.34
K8sClientConfig contains configuration for the K8s client
type K8sInspectClient ¶ added in v0.10.34
type K8sInspectClient interface {
// GetClusterData returns detailed information about workloads, AZs, and storage in a namespace
GetClusterData(ctx context.Context, namespace string) ([]InspectWorkloadItem, []InspectAZItem, []InspectStorageClassItem, error)
// GetSampleData returns sample data for demonstration purposes
GetSampleData(instanceID string) ([]InspectWorkloadItem, []InspectAZItem, []InspectStorageClassItem)
}
K8sInspectClient provides methods for retrieving inspect data
func NewK8sInspectClient ¶ added in v0.10.34
func NewK8sInspectClient(config K8sClientConfig) K8sInspectClient
NewK8sInspectClient creates a new K8s inspection client
type K8sInspectClientImpl ¶ added in v0.10.34
type K8sInspectClientImpl struct {
// contains filtered or unexported fields
}
K8sInspectClientImpl is the Kubernetes implementation of K8sInspectClient
func (*K8sInspectClientImpl) GetClusterData ¶ added in v0.10.34
func (k *K8sInspectClientImpl) GetClusterData(ctx context.Context, namespace string) ([]InspectWorkloadItem, []InspectAZItem, []InspectStorageClassItem, error)
GetClusterData fetches real data from a Kubernetes cluster
func (*K8sInspectClientImpl) GetSampleData ¶ added in v0.10.34
func (k *K8sInspectClientImpl) GetSampleData(instanceID string) ([]InspectWorkloadItem, []InspectAZItem, []InspectStorageClassItem)
GetSampleData returns sample data for demonstration
type LeveledLogger ¶ added in v0.10.2
type LeveledLogger struct {
retryablehttp.LeveledLogger
}
Used to transform the retryablehttp logger to a zerolog logger
func NewLeveledLogger ¶ added in v0.10.2
func NewLeveledLogger() *LeveledLogger
func (*LeveledLogger) Debug ¶ added in v0.10.2
func (l *LeveledLogger) Debug(msg string, keysAndValues ...interface{})
func (*LeveledLogger) Error ¶ added in v0.10.2
func (l *LeveledLogger) Error(msg string, keysAndValues ...interface{})
func (*LeveledLogger) Info ¶ added in v0.10.2
func (l *LeveledLogger) Info(msg string, keysAndValues ...interface{})
func (*LeveledLogger) Warn ¶ added in v0.10.2
func (l *LeveledLogger) Warn(msg string, keysAndValues ...interface{})
type ResourceList ¶ added in v0.10.34
ResourceList is a mapping of resource names to resource quantities
type ResourceRequirements ¶ added in v0.10.34
type ResourceRequirements struct {
Limits ResourceList
Requests ResourceList
}
ResourceRequirements contains resource requirements for a container
Source Files
¶
- account.go
- client.go
- cloudprovider.go
- composegen.go
- deploymentconfig.go
- deploymententity.go
- domain.go
- environment.go
- fleetcustomnetwork.go
- helm.go
- inventory.go
- k8s.go
- k8simplclient.go
- producttier.go
- resource.go
- resourceinstance.go
- service.go
- servicemodel.go
- serviceoffering.go
- servicesorchestration.go
- signin.go
- subscription.go
- upgradepath.go
- user.go
- versionset.go